@@ -32,19 +32,19 @@ templates_path = ['_templates']
 source_suffix = '.rst'
 
 # The master toctree document.
-master_doc = 'contents'
+master_doc = 'index'
 
 # General substitutions.
 project = 'Routes'
-copyright = '2010, Ben Bangert, Mike Orr'
+copyright = '2010-2012, Ben Bangert, Mike Orr'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '1.12.3'
+version = '1.13'
 # The full version, including alpha/beta/rc tags.
-release = '1.12.3'
+release = '1.13'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -76,7 +76,7 @@ pygments_style = 'sphinx'
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
-html_style = 'default.css'
+# html_style = 'default.css'
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -91,14 +91,6 @@ html_style = 'default.css'
 # typographically correct entities.
 #html_use_smartypants = True
 
-html_index = 'index.html'
-
-# Custom sidebar templates, maps document names to template names.
-html_sidebars = {'index': 'indexsidebar.html'}
-
-# Additional templates that should be rendered to pages, maps page names to
-# template names.
-html_additional_pages = {'index': 'index.html'}
 
 html_theme_options = {
     "bgcolor": "#fff",
@@ -133,7 +125,7 @@ html_theme_options = {
 # If true, an OpenSearch description file will be output, and all pages will
 # contain a <link> tag referring to it.  The value of this option must be the
 # base URL from which the finished HTML is served.
-html_use_opensearch = 'http://routes.groovie.org/'
+# html_use_opensearch = 'http://routes.groovie.org/'
 
 # If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
 #html_file_suffix = ''
