@@ -3,7 +3,8 @@ import routes
 
 class TestEnvironment(unittest.TestCase):
     def setUp(self):
-        m = routes.Mapper()
+        m = routes.Mapper(explicit=False)
+        m.minimization = True
         m.connect('archive/:year/:month/:day', controller='blog', action='view', month=None, day=None,
                   requirements={'month':'\d{1,2}','day':'\d{1,2}'})
         m.connect('viewpost/:id', controller='post', action='view')
